@@ -37,6 +37,7 @@ void test_utf8_inout (char **inout);
 GSList *test_filename_return (void);
 
 /* multiple output arguments */
+void test_multi_double_args (gdouble in, gdouble *one, gdouble *two);
 void test_utf8_out_out (char **out0, char **out1);
 char *test_utf8_out_nonconst_return (char **out);
 
@@ -291,6 +292,10 @@ int test_callback_destroy_notify (TestCallbackUserData callback,
                                   gpointer user_data,
                                   GDestroyNotify notify);
 int test_callback_thaw_notifications (void);
+
+void test_callback_async (TestCallbackUserData callback, gpointer user_data);
+int test_callback_thaw_async (void);
+
 int test_callback_infinite (TestCallbackUserData callback,
                            gpointer user_data);
 
